# i18n.lang
A module used for building and translating data to create application internationally

Examples
---
```py
from i18n.lang import i18nLangBuilder
builder = i18nLangBuilder()
builder.generateLang(['spanish', 'french', 'chinese', 'japanese'])
```
